pub struct BigInt {
sign: Sign,
val: u128,
}Expand description
A signed integer in the range [-2^128, 2^128], represented by a u128 and an explicit sign.
In the logic, we work mathematical integers so we could represent them with arbitrary precision
integers. We instead take the simpler approach of using a fixed size representation that allows
us to store any Rust literal, i.e., we can represent both i128::MIN and u128::MAX. This works
because we never do arithmetic. We can change the representation in the future (and use arbitrary
precision integers) if this ever becomes a problem, e.g., if we want to do (precise) arithmetic
during constant folding.
Fields
sign: Signval: u128Implementations
Sourceimpl BigInt
impl BigInt
pub const ZERO: BigInt
pub const ONE: BigInt
pub fn is_negative(&self) -> bool
pub fn abs(&self) -> u128
Sourcepub fn int_min(bit_width: u32) -> BigInt
pub fn int_min(bit_width: u32) -> BigInt
Given the bit width of a signed integer type, produces the minimum integer for that type, i.e., -2^(bit_width - 1).
Sourcepub fn int_max(bit_width: u32) -> BigInt
pub fn int_max(bit_width: u32) -> BigInt
Given the bit width of a signed integer type, produces the maximum integer for that type, i.e., 2^(bit_width - 1) - 1.
Sourcepub fn uint_max(bit_width: u32) -> BigInt
pub fn uint_max(bit_width: u32) -> BigInt
Given the bit width of an unsigned integer type, produces the maximum unsigned integer for that type, i.e., 2^bit_width - 1.
pub fn neg(&self) -> Self
pub fn checked_add(&self, other: &Self) -> Option<Self>
pub fn checked_sub(&self, other: &Self) -> Option<Self>
pub fn checked_mul(&self, other: &Self) -> Option<Self>
pub fn checked_div(&self, other: &Self) -> Option<Self>
pub fn checked_rem(&self, other: &Self) -> Option<Self>