CallGraph

Struct CallGraph 

pub struct CallGraph<'tcx> {
    pub nodes: FxIndexMap<NodeKey<'tcx>, Node<'tcx>>,
    pub callers: UnordMap<NodeKey<'tcx>, Vec<NodeKey<'tcx>>>,
}

Fields

nodes: FxIndexMap<NodeKey<'tcx>, Node<'tcx>>callers: UnordMap<NodeKey<'tcx>, Vec<NodeKey<'tcx>>>

Implementations

Source

impl<'tcx> CallGraph<'tcx>

pub fn new(nodes: FxIndexMap<NodeKey<'tcx>, Node<'tcx>>) -> Self

pub fn resolved_callee( &self, caller: DefId, location: Location, ) -> Option<NodeKey<'tcx>>

The callee node resolved for the Call terminator at location in the body of caller. Returns None for call sites that did not resolve to a concrete node (unresolved trait calls, dynamic dispatch) or whose body is not in the graph.