FluxId

Struct FluxId 

pub struct FluxId<Id> {
    parent: Id,
    name: Symbol,
}
An id for a Flux-specific item that doesn’t have a corresponding Rust item and thus, we cannot identify it with a [DefId]. This includes, for example, associated refinements, qualifiers and refinement functions.

Type-level invariant

This struct maintains a type-level invariant ensuring that the referenced item exists. The id is composed of two parts:

  • parent: A reference to a parent Rust item
  • name: A name uniquely identifiying the item within the parent

Since the name can be an arbitrary Symbol, this doesn’t guarantee the existence of the item, so we must be careful when creating instances of this struct.

Implementation Details

  • Fields are private to ensure construction only through FluxId::new
  • A clippy lint prevents direct usage of FluxId::new, which can be selectively disabled when item existence is guaranteed
  • The type is parametric over the parent Id type to support various id types (e.g., [DefId], MaybeExternId)

Fields

parent: Idname: Symbol

Implementations

Source

impl<Id> FluxId<Id>

pub fn new(parent: Id, name: Symbol) -> Self

pub fn parent(self) -> Id

pub fn name(self) -> Symbol

Source

impl FluxId<DefId>

pub fn as_local(self) -> Option<FluxLocalDefId>

pub fn expect_local(self) -> FluxLocalDefId

pub fn krate(self) -> CrateNum

pub fn index(self) -> FluxId<DefIndex>

Source

impl FluxId<LocalDefId>

pub fn to_def_id(self) -> FluxDefId

pub fn local_def_index(self) -> FluxId<DefIndex>

Source

impl FluxId<MaybeExternId>