pub enum PrimSort {
Int,
Real,
Set,
Map,
RawPtr,
Bool,
Char,
Str,
}Expand description
bool, char, and str are primitive sorts, but because sorts and types are in the same
namespace we resolve them to Res::PrimTy and then make them into a sort during conv
they share their name with the
Variants
Implementations