pub struct FluxItems<'fhir> {
pub items: FxIndexMap<FluxLocalDefId, FluxItem<'fhir>>,
}Expand description
A map between rust definitions and flux annotations in their desugared fhir form.
note: most items in this struct have been moved out into their own query or method in genv. We should eventually get rid of this or change its name.
Fields
items: FxIndexMap<FluxLocalDefId, FluxItem<'fhir>>Implementations