pub struct WeakKvarInfo {
pub solutions: Vec<Binder<Expr>>,
pub sorts: Vec<Sort>,
}Fields
solutions: Vec<Binder<Expr>>Solutions (if provided as ground truth annotations). Each soution is part of a conjunction that constitutes the full ground truth.
sorts: Vec<Sort>The sorts of the weak kvar in the order in which they appear in the arguments.