pub enum TyKind {
Indexed(BaseTy, Expr),
Exists(Binder<Ty>),
Constr(Expr, Ty),
Uninit,
StrgRef(Region, Path, Ty),
Ptr(PtrKind, Path),
Discr(AdtDef, Place),
Param(ParamTy),
Downcast(AdtDef, GenericArgs, Ty, VariantIdx, List<Ty>),
Blocked(Ty),
Infer(TyVid),
}Variants
Indexed(BaseTy, Expr)
Exists(Binder<Ty>)
Constr(Expr, Ty)
Uninit
StrgRef(Region, Path, Ty)
Ptr(PtrKind, Path)
Discr(AdtDef, Place)
This is a bit of a hack. We use this type internally to represent the result of
Rvalue::Discriminant in a way that we can recover the necessary control information
when checking a match. The hack is that we assume the dicriminant remains the same from
the creation of this type until we use it in a match.
Param(ParamTy)
Downcast(AdtDef, GenericArgs, Ty, VariantIdx, List<Ty>)
These only arise when you “narrow” an ADT down to a particular variant;
either EXPLICITLY in a match-of, or IMPLICITLY when you access a field
of a struct to “UNPACK” the struct.
Blocked(Ty)
Infer(TyVid)
A type that needs to be inferred by matching the signature against a rust signature.
TyKind::Infer appear as an intermediate step during conv and should not be present in
the final signature.
Implementations