pub struct Name {
private_use_as_methods_instead: u32 is 0..=4294967040,
}Fields
private_use_as_methods_instead: u32 is 0..=4294967040Implementations
Sourceimpl Name
impl Name
Sourcepub const MAX_AS_U32: u32 = 4294967040
pub const MAX_AS_U32: u32 = 4294967040
Maximum value the index can take, as a u32.
Sourcepub const fn from_usize(value: usize) -> Self
pub const fn from_usize(value: usize) -> Self
Sourcepub const unsafe fn from_u32_unchecked(value: u32) -> Self
pub const unsafe fn from_u32_unchecked(value: u32) -> Self
Creates a new index from a given u32.
Safety
The provided value must be less than or equal to the maximum value for the newtype. Providing a value outside this range is undefined due to layout restrictions.
Prefer using from_u32.