pub struct WKVar {
pub wkvid: WKVid,
pub self_args: usize,
pub args: List<Expr>,
}Expand description
A weak kvar is like a kvar with the exception that it infers the weakest condition necessary instead of the strongest condition. Due to the way we generate these kvars (on fn_sigs, rather than during constraint generation), they also in theory are global.
Fields
wkvid: WKVidself_args: usizeAnalagous to KVar self arguments except we require that instantiations use at least one of the self_args (unless there are none, in which case there is no such requirement).
This is mostly relevant for weak kvars corresponding to function outputs. Consider the signature
foo: fn(x: usize) -> bool{b: $wk1(b, x)}
requires $wk0(x)In this case self_args would be 1 (corresponding to the bool b).
Consider now the snippet
let b = foo(x);
assert(x > 0);Suppose the assertion fails. Without the self_args requirement, we could validly instantiate
$wk1(b, x) := x > 0But this is somewhat nonsensical because only in exceptional cases
does it make sense for foo to somehow “add” information to its
argument (x).
By checking for the presence of at least one self arg, we ensure that the self argument is “used”; fixpoint does a similar check.
This is a syntactic underapproximation and doesn’t preclude things like
$wk1(b, x) := (b => true) && (x > 0)But we could conceive of a more sophisticated check using the self_args.
args: List<Expr>All arguments with self arguments at the beginning.
Implementations