Struct ScalarInt
#[repr(packed(1))]pub struct ScalarInt {
data: u128,
size: NonZero<u8>,
}Expand description
The raw bytes of a simple value.
This is a packed struct in order to allow this type to be optimally embedded in enums (like Scalar).
Fields
data: u128size: NonZero<u8>Auto Trait Implementations
impl DynSend for ScalarInt
impl DynSync for ScalarInt
impl Freeze for ScalarInt
impl RefUnwindSafe for ScalarInt
impl Send for ScalarInt
impl Sync for ScalarInt
impl Unpin for ScalarInt
impl UnsafeUnpin for ScalarInt
impl UnwindSafe for ScalarInt